@@ -2,7 +2,7 @@ package File::Same;
 
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Digest::MD5;
 use File::Spec;
@@ -11,10 +11,10 @@ my %md5s;
 
 sub scan_files {
     my ($original, $files) = @_;
-    
+
     my @results;
     my $orig_md5 = $md5s{$original};
-    
+
     if (!$orig_md5) {
         my $ctx = Digest::MD5->new();
         open(FILE, $original) || die "Cannot open '$original' : $!";
@@ -23,7 +23,7 @@ sub scan_files {
         $orig_md5 = $ctx->hexdigest;
         close(FILE);
     }
-    
+
     foreach my $file (@$files) {
         if (my $md5 = $md5s{$file}) {
             if ($orig_md5 eq $md5) {
@@ -124,7 +124,8 @@ expanded.
 
 =head1 AUTHOR
 
-Matt Sergeant, matt@sergeant.org
+Original author Matt Sergeant, matt@sergeant.org
+Currently maintained by Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 SEE ALSO
 
